@@ -879,6 +879,38 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 	 * {@inheritDoc}
 	 */
 	@Override
+	public List<Notification> getRangeNotificationsByUser(String userid,int from, int quantity) throws NotificationTypeNotFoundException, ColumnNameNotFoundException, NotificationIDNotFoundException {
+		if (from < 1) {
+			throw new IllegalArgumentException("From must be greather than 0");
+		} 
+		ArrayList<Notification> toReturn = new ArrayList<Notification>();
+		ArrayList<String> notificationsIDs = getUserNotificationsIds(userid);
+		
+		//if from is greater than feeds size return empty
+		if (from >=  notificationsIDs.size()) {
+			_log.warn("The starting point of the range is greather than the total number of feeds for this timeline: " + from + " >= " + notificationsIDs.size());
+			return new  ArrayList<Notification>();
+		}
+		
+		int rangeStart = notificationsIDs.size()-from;
+		int rangeEnd = rangeStart-quantity;
+		
+		//check that you reached the end
+		if (rangeEnd<1)
+			rangeEnd = 0;
+		
+		_log.debug("BEFORE starting Point=" + rangeStart + " rangeEnd= " + rangeEnd);
+		//need them in reverse order		
+		for (int i = rangeStart; i > rangeEnd; i--) {
+			Notification toAdd = readNotification(notificationsIDs.get(i));
+			toReturn.add(toAdd);
+		}
+		return toReturn;	
+	}
+	/**
+	 * {@inheritDoc}
+	 */
+	@Override
 	public boolean setAllNotificationReadByUser(String userid) throws NotificationIDNotFoundException, NotificationTypeNotFoundException, ColumnNameNotFoundException {
 		ArrayList<String> notificationsIDs = getUserNotificationsIds(userid);
 
@@ -1046,11 +1078,11 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 			for (int i = 0; i < NotificationType.values().length; i++) {
 				//TODO: Potential bug in NotificationType for workspace are refactored
 				//create a map with all notification enabled except for workspace notifications (They start with WP_) it was the only quick way
-//				if (NotificationType.values()[i].toString().startsWith("WP_") || NotificationType.values()[i].toString().startsWith("CALENDAR")) {
-//					NotificationChannelType[] wpTypes = { NotificationChannelType.PORTAL };
-//					toCreate.put(NotificationType.values()[i], wpTypes);
-//				}
-//				else
+				if (NotificationType.values()[i].toString().startsWith("WP_")) {
+					NotificationChannelType[] wpTypes = { NotificationChannelType.PORTAL };
+					toCreate.put(NotificationType.values()[i], wpTypes);
+				}
+				else
 					toCreate.put(NotificationType.values()[i], NotificationChannelType.values());
 			}
 			setUserNotificationPreferences(userid, toCreate); //commit the map
@@ -1254,7 +1286,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 	 * {@inheritDoc}
 	 */
 	@Override
-	public boolean unlike(String likeid, String feedid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, LikeIDNotFoundException, FeedIDNotFoundException {
+	public boolean unlike(String userid, String likeid, String feedid) throws PrivacyLevelTypeNotFoundException, FeedTypeNotFoundException, ColumnNameNotFoundException, LikeIDNotFoundException, FeedIDNotFoundException {
 		Feed toUpdate = readFeed(feedid);
 		boolean updateLikeNoResult = false;
 
@@ -1262,11 +1294,11 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		if (updateLikeNoResult) {
 			MutationBatch m = conn.getKeyspace().prepareMutationBatch();
 			//delete the row from LikesCF
-			m.withRow(cf_Likes, likeid)
-			.delete();
+			m.withRow(cf_Likes, likeid).delete();
 			//delete the column from UserLikes
-			m.withRow(cf_UserLikedFeeds, likeid)
-			.deleteColumn(likeid);
+			m.withRow(cf_UserLikedFeeds, userid).deleteColumn(likeid);
+			
+			
 
 			try {
 				m.execute();
@@ -1625,4 +1657,5 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 
 
 
+
 }
